@@ -19,7 +19,7 @@ def aguarda_api_subir():
     print(f'{agora}: Conexão estabelecida. Continuando execução...')
 
 def response_logger(response, msg_alternativa=''):
-    agora = datetime.now(timezone=timezone('America/Sao_Paulo'))
+    agora = datetime.now(tz=timezone('America/Sao_Paulo'))
     log_erro = '{agora}: A requisição para {url} falhou. Status {status_code}.'
     if not response.ok:
         print(log_erro.format(**{**locals(), **response.__dict__}))
